package com.phm.manage.mapper;

import com.phm.manage.domain.DeriveParameter;

import java.util.List;

/**
 * 衍生参数信息Mapper接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface DeriveParameterMapper {
    /**
     * 查询衍生参数信息
     *
     * @param id 衍生参数信息主键
     * @return 衍生参数信息
     */
    public DeriveParameter selectDeriveParameterById(Long id);

    /**
     * 查询衍生参数信息列表
     *
     * @param deriveParameter 衍生参数信息
     * @return 衍生参数信息集合
     */
    public List<DeriveParameter> selectDeriveParameterList(DeriveParameter deriveParameter);

    /**
     * 新增衍生参数信息
     *
     * @param deriveParameter 衍生参数信息
     * @return 结果
     */
    public int insertDeriveParameter(DeriveParameter deriveParameter);

    /**
     * 修改衍生参数信息
     *
     * @param deriveParameter 衍生参数信息
     * @return 结果
     */
    public int updateDeriveParameter(DeriveParameter deriveParameter);

    /**
     * 删除衍生参数信息
     *
     * @param id 衍生参数信息主键
     * @return 结果
     */
    public int deleteDeriveParameterById(Long id);

    /**
     * 批量删除衍生参数信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDeriveParameterByIds(Long[] ids);
}
